package javax.swing.text.html;

import javax.swing.text.EditorKit;
import sun.swing.text.html.FrameEditorPaneTag;
import javax.swing.text.ViewFactory;
import javax.swing.event.DocumentEvent;
import javax.swing.event.HyperlinkEvent;
import javax.swing.JViewport;
import java.awt.Dimension;
import javax.swing.text.AttributeSet;
import java.awt.Insets;
import java.awt.Shape;
import java.awt.Graphics;
import javax.swing.text.JTextComponent;
import javax.swing.text.View;
import java.awt.Container;
import javax.swing.text.Document;
import java.io.IOException;
import java.net.MalformedURLException;
import java.awt.Component;
import javax.swing.text.Element;
import java.net.URL;
import javax.swing.JScrollPane;
import javax.swing.JEditorPane;
import javax.swing.event.HyperlinkListener;
import javax.swing.text.ComponentView;

class FrameView extends ComponentView implements HyperlinkListener
{
    JEditorPane htmlPane;
    JScrollPane scroller;
    boolean editable;
    float width;
    float height;
    URL src;
    private boolean createdComponent;
    
    public FrameView(Element elem) {
        super(elem);
    }
    
    @Override
    protected Component createComponent() {
        Element element = this.getElement();
        String spec = (String)element.getAttributes().getAttribute(HTML.Attribute.SRC);
        if (spec != null && !spec.equals("")) {
            try {
                this.src = new URL(((HTMLDocument)element.getDocument()).getBase(), spec);
                (this.htmlPane = new FrameView.FrameEditorPane()).addHyperlinkListener(this);
                JEditorPane hostPane = this.getHostPane();
                boolean autoFormSubmission = true;
                if (hostPane != null) {
                    this.htmlPane.setEditable(hostPane.isEditable());
                    String value = (String)hostPane.getClientProperty("charset");
                    if (value != null) {
                        this.htmlPane.putClientProperty("charset", value);
                    }
                    HTMLEditorKit htmlEditorKit = (HTMLEditorKit)hostPane.getEditorKit();
                    if (htmlEditorKit != null) {
                        autoFormSubmission = htmlEditorKit.isAutoFormSubmission();
                    }
                }
                this.htmlPane.setPage(this.src);
                HTMLEditorKit htmlEditorKit2 = (HTMLEditorKit)this.htmlPane.getEditorKit();
                if (htmlEditorKit2 != null) {
                    htmlEditorKit2.setAutoFormSubmission((boolean)autoFormSubmission);
                }
                Document document = this.htmlPane.getDocument();
                if ((document instanceof HTMLDocument)) {
                    ((HTMLDocument)document).setFrameDocumentState(true);
                }
                this.setMargin();
                this.createScrollPane();
                this.setBorder();
            }
            catch (MalformedURLException ex) {
                ex.printStackTrace();
            }
            catch (IOException ex2) {
                ex2.printStackTrace();
            }
        }
        this.createdComponent = true;
        return this.scroller;
    }
    
    JEditorPane getHostPane() {
        Container container;
        for (container = this.getContainer(); container != null && !(container instanceof JEditorPane); container = container.getParent()) {}
        return (JEditorPane)container;
    }
    
    @Override
    public void setParent(View parent) {
        if (parent != null) {
            this.editable = ((JTextComponent)parent.getContainer()).isEditable();
        }
        super.setParent(parent);
    }
    
    @Override
    public void paint(Graphics g, Shape a) {
        Container container = this.getContainer();
        if (container != null && this.htmlPane != null && this.htmlPane.isEditable() != ((JTextComponent)container).isEditable()) {
            this.editable = ((JTextComponent)container).isEditable();
            this.htmlPane.setEditable(this.editable);
        }
        super.paint(g, a);
    }
    
    private void setMargin() {
        Insets margin = this.htmlPane.getMargin();
        boolean n = false;
        AttributeSet attributes = this.getElement().getAttributes();
        String s = (String)attributes.getAttribute(HTML.Attribute.MARGINWIDTH);
        Insets margin2;
        if (margin != null) {
            margin2 = new Insets(margin.top, margin.left, margin.right, margin.bottom);
        }
        else {
            margin2 = new Insets(0, 0, 0, 0);
        }
        if (s != null) {
            int int1 = Integer.parseInt(s);
            if (int1 > 0) {
                margin2.left = int1;
                margin2.right = int1;
                n = true;
            }
        }
        String s2 = (String)attributes.getAttribute(HTML.Attribute.MARGINHEIGHT);
        if (s2 != null) {
            int int2 = Integer.parseInt(s2);
            if (int2 > 0) {
                margin2.top = int2;
                margin2.bottom = int2;
                n = true;
            }
        }
        if (!(n == 0)) {
            this.htmlPane.setMargin(margin2);
        }
    }
    
    private void setBorder() {
        String s = (String)this.getElement().getAttributes().getAttribute(HTML.Attribute.FRAMEBORDER);
        if (s != null && (s.equals("no") || s.equals("0"))) {
            this.scroller.setBorder(null);
        }
    }
    
    private void createScrollPane() {
        String s = (String)this.getElement().getAttributes().getAttribute(HTML.Attribute.SCROLLING);
        if (s == null) {
            s = "auto";
        }
        if (!s.equals("no")) {
            if (s.equals("yes")) {
                this.scroller = new JScrollPane(22, 32);
            }
            else {
                this.scroller = new JScrollPane();
            }
        }
        else {
            this.scroller = new JScrollPane(21, 31);
        }
        JViewport viewport = this.scroller.getViewport();
        viewport.add(this.htmlPane);
        viewport.setBackingStoreEnabled(true);
        this.scroller.setMinimumSize(new Dimension(5, 5));
        this.scroller.setMaximumSize(new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE));
    }
    
    JEditorPane getOutermostJEditorPane() {
        View view = this.getParent();
        FrameSetView frameSetView = null;
        while (view != null) {
            if ((view instanceof FrameSetView)) {
                frameSetView = (FrameSetView)view;
            }
            view = view.getParent();
        }
        if (frameSetView != null) {
            return (JEditorPane)frameSetView.getContainer();
        }
        return null;
    }
    
    private boolean inNestedFrameSet() {
        return ((View)this.getParent()).getParent() instanceof FrameSetView;
    }
    
    @Override
    public void hyperlinkUpdate(HyperlinkEvent hyperlinkEvent) {
        JEditorPane outermostJEditorPane = this.getOutermostJEditorPane();
        if (outermostJEditorPane == null) {
            return;
        }
        if (!(hyperlinkEvent instanceof HTMLFrameHyperlinkEvent)) {
            outermostJEditorPane.fireHyperlinkUpdate(hyperlinkEvent);
            return;
        }
        HTMLFrameHyperlinkEvent htmlFrameHyperlinkEvent = (HTMLFrameHyperlinkEvent)hyperlinkEvent;
        if (htmlFrameHyperlinkEvent.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
            String target = htmlFrameHyperlinkEvent.getTarget();
            if (target.equals("_parent") && !this.inNestedFrameSet()) {
                target = "_top";
            }
            if ((hyperlinkEvent instanceof FormSubmitEvent)) {
                HTMLEditorKit htmlEditorKit = (HTMLEditorKit)outermostJEditorPane.getEditorKit();
                if (htmlEditorKit != null && htmlEditorKit.isAutoFormSubmission()) {
                    if (target.equals("_top")) {
                        try {
                            this.movePostData(outermostJEditorPane, target);
                            outermostJEditorPane.setPage(htmlFrameHyperlinkEvent.getURL());
                        }
                        catch (IOException ex2) {}
                    }
                    else {
                        ((HTMLDocument)outermostJEditorPane.getDocument()).processHTMLFrameHyperlinkEvent(htmlFrameHyperlinkEvent);
                    }
                }
                else {
                    outermostJEditorPane.fireHyperlinkUpdate(hyperlinkEvent);
                }
                return;
            }
            else {
                if (target.equals("_top")) {
                    try {
                        outermostJEditorPane.setPage(htmlFrameHyperlinkEvent.getURL());
                    }
                    catch (IOException ex) {}
                }
                if (!outermostJEditorPane.isEditable()) {
                    outermostJEditorPane.fireHyperlinkUpdate(new HTMLFrameHyperlinkEvent(outermostJEditorPane, htmlFrameHyperlinkEvent.getEventType(), htmlFrameHyperlinkEvent.getURL(), htmlFrameHyperlinkEvent.getDescription(), this.getElement(), htmlFrameHyperlinkEvent.getInputEvent(), target));
                }
            }
        }
        return;
    }
    
    @Override
    public void changedUpdate(DocumentEvent documentEvent, Shape shape, ViewFactory viewFactory) {
        Element element = this.getElement();
        AttributeSet attributes = element.getAttributes();
        URL src = this.src;
        String spec = (String)attributes.getAttribute(HTML.Attribute.SRC);
        URL base = ((HTMLDocument)element.getDocument()).getBase();
        try {
            if (!this.createdComponent) {
                return;
            }
            Object movePostData = this.movePostData(this.htmlPane, null);
            this.src = new URL(base, spec);
            if (src.equals(this.src) && this.src.getRef() == null && movePostData == null) {
                return;
            }
            this.htmlPane.setPage(this.src);
            Document document = this.htmlPane.getDocument();
            if ((document instanceof HTMLDocument)) {
                ((HTMLDocument)document).setFrameDocumentState(true);
            }
        }
        catch (MalformedURLException ex) {}
        catch (IOException ex2) {}
    }
    
    private Object movePostData(JEditorPane editorPane, String str) {
        Object property = null;
        JEditorPane outermostJEditorPane = this.getOutermostJEditorPane();
        if (outermostJEditorPane != null) {
            if (str == null) {
                str = (String)this.getElement().getAttributes().getAttribute(HTML.Attribute.NAME);
            }
            if (str != null) {
                String string = "javax.swing.JEditorPane.postdata." + str;
                Document document = outermostJEditorPane.getDocument();
                property = document.getProperty(string);
                if (property != null) {
                    editorPane.getDocument().putProperty("javax.swing.JEditorPane.postdata", property);
                    document.putProperty(string, null);
                }
            }
        }
        return property;
    }
    
    @Override
    public float getMinimumSpan(int n) {
        return 5.0f;
    }
    
    @Override
    public float getMaximumSpan(int n) {
        return 2.1474836E9f;
    }
    
    class FrameEditorPane extends JEditorPane implements FrameEditorPaneTag
    {
        @Override
        public EditorKit getEditorKitForContentType(String type) {
            EditorKit editorKitForContentType = super.getEditorKitForContentType(type);
            JEditorPane outermostJEditorPane;
            if ((outermostJEditorPane = FrameView.this.getOutermostJEditorPane()) != null) {
                EditorKit editorKitForContentType2 = outermostJEditorPane.getEditorKitForContentType(type);
                if (!editorKitForContentType.getClass().equals(editorKitForContentType2.getClass())) {
                    editorKitForContentType = (EditorKit)editorKitForContentType2.clone();
                    this.setEditorKitForContentType(type, editorKitForContentType);
                }
            }
            return editorKitForContentType;
        }
        
        FrameView getFrameView() {
            return FrameView.this;
        }
    }
}
